FastDebounce class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

count int
获取当前发抖数量
no setter

Static Methods

cancel(String tag) → void
取消发抖
cancelAll() → void
取消所有发抖
debounce({required String tag, required Duration duration, required FastDebounceVoidCallback onExecute}) → void
fire(String tag) → void
Fires the callback associated with tag immediately. This does not cancel the debounce timer, so if you want to invoke the callback and cancel the debounce timer, you must first call fire(tag) and then cancel(tag).