FastThrottle class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
cancel(
String tag) → void - 取消节流
-
cancelAll(
) → void - 取消全部节流
-
throttle(
{required String tag, required Duration duration, required FastThrottleVoidCallback onExecute, FastThrottleVoidCallback? onAfter}) → bool